@@ -66,7 +66,7 @@ if __name__ == '__main__':
             import redis
             from redis.commands.graph import Graph
             r = redis.Redis(host=args.host,port=args.port,password=args.password)
-            graph = Graph(args.graph,r)
+            graph = Graph(r,args.graph)
 
             item_count = 0
 
